Phys - Cosmic Ray
=================

This subpackage of phys includes some tools commonly used in cosmic ray physics.
It includes standard parametrizations of the cosmic ray fluxes,
some data from various experiments, and some typical functions used
in the analysis of cosmic rays.
